package ballerina.utils;

@doc:Description ("Decodes a Base64 encoded string to a new string")
@doc:Param ("s: The input string to be decoded" )
@doc:Return ("string: The decoded string" )
native function base64decode (string s) (string);

@doc:Description ("Encodes the specified string into a string using the Base64 scheme")
@doc:Param ("s: The input string to be encoded" )
@doc:Return ("string: The encoded string" )
native function base64encode (string s) (string);

@doc:Description ("Encodes a Base64 encoded string into a Base16 encoded string.")
@doc:Param ("baseString: The input string to be encoded" )
@doc:Return ("string: The Base16 encoded string" )
native function base64ToBase16Encode (string baseString) (string);

@doc:Description ("Returns a hash of a given string using the SHA-256 algorithm ")
@doc:Param ("baseString: The string to be hashed" )
@doc:Param ("algorithm: The hashing algorithm to be used" )
@doc:Return ("string: The hashed string" )
native function getHash (string baseString, string algorithm) (string);

@doc:Description ("Returns a hash of a given string using the key provided ")
@doc:Param ("baseString: The string to be hashed" )
@doc:Param ("keyString: The key string " )
@doc:Param ("algorithm: The hashing algorithm to be used" )
@doc:Return ("string: The hashed string" )
native function getHmac (string baseString, string keyString, string algorithm) (string);

@doc:Description ("Returns a hash of a given string in Base64 format using the key provided ")
@doc:Param ("baseString: The string to be hashed" )
@doc:Param ("keyString: The key string " )
@doc:Param ("algorithm: The hashing algorithm to be used" )
@doc:Return ("string: The hashed string" )
native function getHmacFromBase64 (string baseString, string keyString, string algorithm) (string);

@doc:Description ("Returns a random UUID string")
@doc:Return ("string: The random string" )
native function getRandomString () (string);

